# WARNING: Please don't edit this file. It was generated by Python/WinRT v2.0.1

import winrt.system
from winrt import _winrt_windows_storage_bulkaccess

__all__ = [
    "FileInformation",
    "FileInformationFactory",
    "FolderInformation",
    "IStorageItemInformation",
]

FileInformation = _winrt_windows_storage_bulkaccess.FileInformation
FileInformationFactory = _winrt_windows_storage_bulkaccess.FileInformationFactory
FolderInformation = _winrt_windows_storage_bulkaccess.FolderInformation
IStorageItemInformation = _winrt_windows_storage_bulkaccess.IStorageItemInformation
